@@ -203,7 +203,7 @@ QT_WARNING_POP
         // take care of user style changes, setting back colors and stuff
 
         // apply GUI settings
-        emit appearanceChanged();
+        Q_EMIT appearanceChanged();
 
         if (Preferences::self()->showTrayIcon() && Preferences::self()->hideToTrayOnStartup())
             mainWindow->hide();
@@ -326,7 +326,7 @@ bool Application::event(QEvent* event)
 {
     if (event->type() == QEvent::ApplicationPaletteChange
         || event->type() == QEvent::ApplicationFontChange) {
-        emit appearanceChanged();
+        Q_EMIT appearanceChanged();
     }
 
     return QApplication::event(event);
@@ -957,7 +957,7 @@ void Application::saveOptions(bool updateGUI)
     KSharedConfig::openConfig()->sync();
 
     if(updateGUI)
-        emit appearanceChanged();
+        Q_EMIT appearanceChanged();
 }
 
 void Application::fetchQueueRates()
@@ -1019,7 +1019,7 @@ void Application::storeUrl(const QString& origin, const QString& newUrl, const Q
     m_urlModel->setData(m_urlModel->index(0, 0), origin, Qt::DisplayRole);
     m_urlModel->setData(m_urlModel->index(0, 1), url, Qt::DisplayRole);
 
-    UrlDateItem* dateItem = new UrlDateItem(dateTime);
+    auto* dateItem = new UrlDateItem(dateTime);
     m_urlModel->setItem(0, 2, dateItem);
 }
 
