@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2006 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2006 John Tapsell <johnflux@gmail.com>
+    SPDX-FileCopyrightText: 2006 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2006 John Tapsell <johnflux@gmail.com>
 */
 
 #ifndef IGNORE_CONFIG_H
@@ -22,9 +17,8 @@ class Ignore_Config : public QWidget, public KonviSettingsPage, private Ui::Igno
     Q_OBJECT
 
     public:
-        explicit Ignore_Config( QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = 0 );
-        ~Ignore_Config() override;
-        QString flagNames;
+        explicit Ignore_Config( QWidget* parent = nullptr, const char* name = nullptr, Qt::WindowFlags fl = {} );
+        ~Ignore_Config();
 
         void restorePageToDefaults() override;
         void saveSettings() override;
@@ -32,24 +26,28 @@ class Ignore_Config : public QWidget, public KonviSettingsPage, private Ui::Igno
 
         bool hasChanged() override;
 
-    private:
-        QStringList m_oldIgnoreList;
-
-        QStringList currentIgnoreList();  // in hasChanged() format
-        QList<Ignore*> getIgnoreList(); // in prefs format
-        void updateEnabledness();
-
     public Q_SLOTS:
         virtual void languageChange();
 
-    protected Q_SLOTS:
+    Q_SIGNALS:
+        void modified();
+
+    private Q_SLOTS:
         void newIgnore();
         void removeIgnore();
         void flagCheckboxChanged();
         void select(QTreeWidgetItem* item);
         void removeAllIgnore();
-    Q_SIGNALS:
-        void modified();
+
+    private:
+        QStringList currentIgnoreList() const;  // in hasChanged() format
+        QList<Ignore*> getIgnoreList() const; // in prefs format
+        void updateEnabledness();
+
+    private:
+        QStringList m_oldIgnoreList;
+
+        Q_DISABLE_COPY(Ignore_Config)
 };
 
 #endif // IGNORE_CONFIG_H
