@@ -1,12 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2008 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2008 Eike Hein <hein@kde.org>
 */
 
 #include "connectionsettings.h"
@@ -18,7 +13,7 @@ ConnectionSettings::ConnectionSettings()
     m_reconnectCount = 0;
 }
 
-bool ConnectionSettings::isValid()
+bool ConnectionSettings::isValid() const
 {
     if (m_server.host().isEmpty()) return false;
 
