@@ -376,7 +376,7 @@ MainWindow::MainWindow() : KXmlGuiWindow(nullptr)
 
     QStringList encodingDescs = Konversation::IRCCharsets::self()->availableEncodingDescriptiveNames();
     encodingDescs.prepend(i18n("Default"));
-    KSelectAction* selectAction = new KSelectAction(this);
+    auto* selectAction = new KSelectAction(this);
     selectAction->setEditable(false);
     selectAction->setItems(encodingDescs);
     selectAction->setEnabled(false);
@@ -450,7 +450,7 @@ MainWindow::MainWindow() : KXmlGuiWindow(nullptr)
     connect(action, &QAction::triggered, m_viewContainer, &ViewContainer::clearAllViews);
     actionCollection()->addAction(QStringLiteral("clear_tabs"), action);
 
-    KToggleAction* awayAction = new KToggleAction(this);
+    auto* awayAction = new KToggleAction(this);
     awayAction->setText(i18n("Global Away"));
     actionCollection()->setDefaultShortcut(awayAction,QKeySequence(QStringLiteral("Ctrl+Shift+A")));
     awayAction->setEnabled(false);
@@ -520,7 +520,7 @@ MainWindow::MainWindow() : KXmlGuiWindow(nullptr)
     connect(action, &QAction::triggered, m_viewContainer, &ViewContainer::closeQueries);
     actionCollection()->addAction(QStringLiteral("close_queries"), action);
 
-    KToggleAction* toggleChannelNickListsAction = new KToggleAction(this);
+    auto* toggleChannelNickListsAction = new KToggleAction(this);
     if (Preferences::self()->showNickList())
         toggleChannelNickListsAction->setChecked(true);
     toggleChannelNickListsAction->setText(i18n("Show Nicklist"));
@@ -545,7 +545,7 @@ MainWindow::MainWindow() : KXmlGuiWindow(nullptr)
     // Bookmarks
     action=new QAction(this);
     action->setText(i18n("Bookmarks"));
-    QMenu *menu = new QMenu(this);
+    auto *menu = new QMenu(this);
     action->setMenu(menu);
     new KonviBookmarkHandler(menu, this);
     actionCollection()->addAction(QStringLiteral("bookmarks") , action);
@@ -669,7 +669,7 @@ bool MainWindow::queryClose()
 
 void MainWindow::hideEvent(QHideEvent *e)
 {
-    emit triggerRememberLine();
+    Q_EMIT triggerRememberLine();
 
     m_statusBar->clearMainLabelTempText();
 
@@ -678,7 +678,7 @@ void MainWindow::hideEvent(QHideEvent *e)
 
 void MainWindow::showEvent(QShowEvent *e)
 {
-    emit cancelRememberLine();
+    Q_EMIT cancelRememberLine();
 
     KXmlGuiWindow::showEvent(e);
 }
@@ -698,15 +698,15 @@ bool MainWindow::event(QEvent* e)
     }
     else if (e->type() == QEvent::WindowActivate)
     {
-        emit endNotification();
-        emit cancelRememberLine();
+        Q_EMIT endNotification();
+        Q_EMIT cancelRememberLine();
     }
     else if(e->type() == QEvent::WindowDeactivate)
     {
         m_statusBar->clearMainLabelTempText();
 
         if (qApp->activeModalWidget() == nullptr)
-            emit triggerRememberLine();
+            Q_EMIT triggerRememberLine();
     }
 
     return KXmlGuiWindow::event(e);
@@ -853,7 +853,7 @@ void MainWindow::openServerList()
 
 void MainWindow::openQuickConnectDialog()
 {
-    emit showQuickConnectDialog();
+    Q_EMIT showQuickConnectDialog();
 }
 
 
@@ -904,7 +904,7 @@ void MainWindow::notifyAction(int connectionId, const QString& nick)
 // TODO: Let an own class handle notify things
 void MainWindow::setOnlineList(Server* notifyServer,const QStringList& /*list*/, bool /*changed*/)
 {
-    emit nicksNowOnline(notifyServer);
+    Q_EMIT nicksNowOnline(notifyServer);
     // FIXME  if (changed && nicksOnlinePanel) newText(nicksOnlinePanel, QString(), true);
 }
 
