@@ -1,15 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  This class handles the system tray icon
-  begin:     Sun Nov 9 2003
-  copyright: (C) 2003 by Peter Simonsson
-  email:     psn@linux.se
+    SPDX-FileCopyrightText: 2003 Peter Simonsson <psn@linux.se>
 */
 
 #ifndef TRAYICON_H
@@ -19,13 +11,16 @@
 
 namespace Konversation
 {
+    /**
+     * This class handles the system tray icon
+     */
     class TrayIcon : public KStatusNotifierItem
     {
         Q_OBJECT
 
         public:
-            explicit TrayIcon(QWidget* parent = 0);
-            ~TrayIcon() override;
+            explicit TrayIcon(QWidget* parent = nullptr);
+            ~TrayIcon();
 
             bool notificationEnabled() { return m_notificationEnabled; }
 
@@ -41,6 +36,8 @@ namespace Konversation
         private:
             bool m_notificationEnabled;
             bool m_away;
+
+            Q_DISABLE_COPY(TrayIcon)
     };
 }
 
